@@ -112,7 +112,8 @@ static void print_req(gnutls_buffer_st * str, gnutls_ocsp_req_t req)
 		if (indx == 0)
 			adds(str, "\tExtensions:\n");
 
-		if (memcmp(oid.data, GNUTLS_OCSP_NONCE, oid.size) == 0) {
+		if (oid.size == sizeof(GNUTLS_OCSP_NONCE) &&
+		    memcmp(oid.data, GNUTLS_OCSP_NONCE, oid.size) == 0) {
 			gnutls_datum_t nonce;
 			unsigned int critical;
 
@@ -469,7 +470,8 @@ print_resp(gnutls_buffer_st * str, gnutls_ocsp_resp_t resp,
 			continue;
 		}
 
-		if (memcmp(oid.data, GNUTLS_OCSP_NONCE, oid.size) == 0) {
+		if (oid.size == sizeof(GNUTLS_OCSP_NONCE) &&
+		    memcmp(oid.data, GNUTLS_OCSP_NONCE, oid.size) == 0) {
 			gnutls_datum_t nonce;
 			unsigned int critical;
 
